@@ -2,7 +2,7 @@ package Date::Holidays::TW;
 use strict;
 use utf8;
 
-our $VERSION = v0.2.0;
+our $VERSION = v0.3.0;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(is_tw_holiday tw_holidays);
@@ -1008,30 +1008,253 @@ my %CAL = (
         "1226" => "星期六、星期日",
         "1227" => "星期六、星期日",
     },
-);
+    2021 => {
+        "0101" => "中華民國開國紀念日",
+        "0102" => "星期六、星期日",
+        "0103" => "星期六、星期日",
+        "0109" => "星期六、星期日",
+        "0110" => "星期六、星期日",
+        "0116" => "星期六、星期日",
+        "0117" => "星期六、星期日",
+        "0123" => "星期六、星期日",
+        "0124" => "星期六、星期日",
+        "0130" => "星期六、星期日",
+        "0131" => "星期六、星期日",
+        "0206" => "星期六、星期日",
+        "0207" => "星期六、星期日",
+        "0210" => "調整放假日",
+        "0211" => "農曆除夕",
+        "0212" => "春節",
+        "0213" => "春節",
+        "0214" => "春節",
+        "0215" => "補假",
+        "0216" => "補假",
+        "0220" => "",
+        "0221" => "星期六、星期日",
+        "0227" => "星期六、星期日",
+        "0228" => "和平紀念日",
+        "0301" => "補假",
+        "0306" => "星期六、星期日",
+        "0307" => "星期六、星期日",
+        "0313" => "星期六、星期日",
+        "0314" => "星期六、星期日",
+        "0320" => "星期六、星期日",
+        "0321" => "星期六、星期日",
+        "0327" => "星期六、星期日",
+        "0328" => "星期六、星期日",
+        "0402" => "補假",
+        "0403" => "星期六、星期日",
+        "0404" => "兒童節及民族掃墓節",
+        "0405" => "補假",
+        "0410" => "星期六、星期日",
+        "0411" => "星期六、星期日",
+        "0417" => "星期六、星期日",
+        "0418" => "星期六、星期日",
+        "0424" => "星期六、星期日",
+        "0425" => "星期六、星期日",
+        "0501" => "星期六、星期日",
+        "0502" => "星期六、星期日",
+        "0508" => "星期六、星期日",
+        "0509" => "星期六、星期日",
+        "0515" => "星期六、星期日",
+        "0516" => "星期六、星期日",
+        "0522" => "星期六、星期日",
+        "0523" => "星期六、星期日",
+        "0529" => "星期六、星期日",
+        "0530" => "星期六、星期日",
+        "0605" => "星期六、星期日",
+        "0606" => "星期六、星期日",
+        "0612" => "星期六、星期日",
+        "0613" => "星期六、星期日",
+        "0614" => "端午節",
+        "0619" => "星期六、星期日",
+        "0620" => "星期六、星期日",
+        "0626" => "星期六、星期日",
+        "0627" => "星期六、星期日",
+        "0703" => "星期六、星期日",
+        "0704" => "星期六、星期日",
+        "0710" => "星期六、星期日",
+        "0711" => "星期六、星期日",
+        "0717" => "星期六、星期日",
+        "0718" => "星期六、星期日",
+        "0724" => "星期六、星期日",
+        "0725" => "星期六、星期日",
+        "0731" => "星期六、星期日",
+        "0801" => "星期六、星期日",
+        "0807" => "星期六、星期日",
+        "0808" => "星期六、星期日",
+        "0814" => "星期六、星期日",
+        "0815" => "星期六、星期日",
+        "0821" => "星期六、星期日",
+        "0822" => "星期六、星期日",
+        "0828" => "星期六、星期日",
+        "0829" => "星期六、星期日",
+        "0903" => "",
+        "0904" => "星期六、星期日",
+        "0905" => "星期六、星期日",
+        "0911" => "",
+        "0912" => "星期六、星期日",
+        "0918" => "星期六、星期日",
+        "0919" => "星期六、星期日",
+        "0920" => "調整放假日",
+        "0921" => "中秋節",
+        "0925" => "星期六、星期日",
+        "0926" => "星期六、星期日",
+        "1002" => "星期六、星期日",
+        "1003" => "星期六、星期日",
+        "1009" => "星期六、星期日",
+        "1010" => "國慶日",
+        "1011" => "補假",
+        "1016" => "星期六、星期日",
+        "1017" => "星期六、星期日",
+        "1023" => "星期六、星期日",
+        "1024" => "星期六、星期日",
+        "1030" => "星期六、星期日",
+        "1031" => "星期六、星期日",
+        "1106" => "星期六、星期日",
+        "1107" => "星期六、星期日",
+        "1113" => "星期六、星期日",
+        "1114" => "星期六、星期日",
+        "1120" => "星期六、星期日",
+        "1121" => "星期六、星期日",
+        "1127" => "星期六、星期日",
+        "1128" => "星期六、星期日",
+        "1204" => "星期六、星期日",
+        "1205" => "星期六、星期日",
+        "1211" => "星期六、星期日",
+        "1212" => "星期六、星期日",
+        "1218" => "星期六、星期日",
+        "1219" => "星期六、星期日",
+        "1225" => "星期六、星期日",
+        "1226" => "星期六、星期日",
+        "1231" => "補假",
+    },
 
-$CAL{2021} = {
-    '0101' => '中華民國開國紀念日',
-    '0210' => '春節',
-    '0211' => '春節',
-    '0212' => '春節',
-    '0213' => '春節',
-    '0214' => '春節',
-    '0215' => '春節',
-    '0216' => '春節',
-    '0220' => '',
-    '0228' => '和平紀念日',
-    '0301' => '調整放假',
-    '0402' => '調整放假',
-    '0404' => '兒童節',
-    '0405' => '調整放假',
-    '0614' => '端午節',
-    '0911' => ''
-    '0920' => '調整放假'
-    '0921' => '中秋節',
-    '1010' => '國慶日',
-    '1011' => '調整放假',
-};
+    2022 => {
+        "0101" => "中華民國開國紀念日",
+        "0102" => "星期六、星期日",
+        "0108" => "星期六、星期日",
+        "0109" => "星期六、星期日",
+        "0115" => "星期六、星期日",
+        "0116" => "星期六、星期日",
+        "0123" => "星期六、星期日",
+        "0129" => "星期六、星期日",
+        "0130" => "星期六、星期日",
+        "0131" => "調整放假日",
+        "0201" => "農曆除夕",
+        "0202" => "春節",
+        "0233" => "春節",
+        "0204" => "春節",
+        "0205" => "星期六、星期日",
+        "0206" => "星期六、星期日",
+        "0212" => "星期六、星期日",
+        "0213" => "星期六、星期日",
+        "0219" => "星期六、星期日",
+        "0220" => "星期六、星期日",
+        "0226" => "星期六、星期日",
+        "0227" => "星期六、星期日",
+        "0228" => "和平紀念日",
+        "0305" => "星期六、星期日",
+        "0306" => "星期六、星期日",
+        "0312" => "星期六、星期日",
+        "0313" => "星期六、星期日",
+        "0319" => "星期六、星期日",
+        "0320" => "星期六、星期日",
+        "0326" => "星期六、星期日",
+        "0327" => "星期六、星期日",
+
+        "0402" => "星期六、星期日",
+        "0403" => "星期六、星期日",
+        "0404" => "兒童節",
+        "0405" => "民族掃墓節",
+        "0409" => "星期六、星期日",
+        "0410" => "星期六、星期日",
+        "0416" => "星期六、星期日",
+        "0417" => "星期六、星期日",
+        "0423" => "星期六、星期日",
+        "0424" => "星期六、星期日",
+        "0430" => "星期六、星期日",
+        "0501" => "星期六、星期日",
+        "0507" => "星期六、星期日",
+        "0508" => "星期六、星期日",
+        "0514" => "星期六、星期日",
+        "0515" => "星期六、星期日",
+        "0521" => "星期六、星期日",
+        "0522" => "星期六、星期日",
+        "0528" => "星期六、星期日",
+        "0529" => "星期六、星期日",
+        "0603" => "端午節",
+        "0604" => "星期六、星期日",
+        "0605" => "星期六、星期日",
+        "0611" => "星期六、星期日",
+        "0612" => "星期六、星期日",
+        "0618" => "星期六、星期日",
+        "0619" => "星期六、星期日",
+        "0625" => "星期六、星期日",
+        "0626" => "星期六、星期日",
+
+        "0702" => "星期六、星期日",
+        "0703" => "星期六、星期日",
+        "0709" => "星期六、星期日",
+        "0710" => "星期六、星期日",
+        "0716" => "星期六、星期日",
+        "0717" => "星期六、星期日",
+        "0723" => "星期六、星期日",
+        "0724" => "星期六、星期日",
+        "0730" => "星期六、星期日",
+        "0731" => "星期六、星期日",
+
+        "0806" => "星期六、星期日",
+        "0807" => "星期六、星期日",
+        "0813" => "星期六、星期日",
+        "0814" => "星期六、星期日",
+        "0820" => "星期六、星期日",
+        "0821" => "星期六、星期日",
+        "0827" => "星期六、星期日",
+        "0828" => "星期六、星期日",
+
+        "0903" => "星期六、星期日",
+        "0904" => "星期六、星期日",
+        "0909" => "調整放假日",
+        "0910" => "中秋節",
+        "0911" => "星期六、星期日",
+        "0917" => "星期六、星期日",
+        "0918" => "星期六、星期日",
+        "0924" => "星期六、星期日",
+        "0925" => "星期六、星期日",
+
+        "1001" => "星期六、星期日",
+        "1002" => "星期六、星期日",
+        "1008" => "星期六、星期日",
+        "1009" => "星期六、星期日",
+        "1010" => "國慶日",
+        "1015" => "星期六、星期日",
+        "1016" => "星期六、星期日",
+        "1022" => "星期六、星期日",
+        "1023" => "星期六、星期日",
+        "1029" => "星期六、星期日",
+        "1030" => "星期六、星期日",
+
+        "1105" => "星期六、星期日",
+        "1106" => "星期六、星期日",
+        "1112" => "星期六、星期日",
+        "1113" => "星期六、星期日",
+        "1119" => "星期六、星期日",
+        "1120" => "星期六、星期日",
+        "1126" => "星期六、星期日",
+        "1127" => "星期六、星期日",
+
+        "1203" => "星期六、星期日",
+        "1204" => "星期六、星期日",
+        "1210" => "星期六、星期日",
+        "1211" => "星期六、星期日",
+        "1217" => "星期六、星期日",
+        "1218" => "星期六、星期日",
+        "1224" => "星期六、星期日",
+        "1225" => "星期六、星期日",
+        "1231" => "星期六、星期日",
+    },
+);
 
 sub new { bless {}, shift };
 
